import { LitElement } from 'lit';
import { HslaColor } from 'colord';
import { UUIColorAreaEvent } from '@umbraco-ui/uui-color-area/lib';
import { UUIColorSliderEvent } from '@umbraco-ui/uui-color-slider/lib';
import { UUIColorSwatchesElement, UUIColorSwatchesEvent } from '@umbraco-ui/uui-color-swatches/lib';
import { UUIInputElement } from '@umbraco-ui/uui-input/lib';
export type UUIColorPickerFormat = 'hex' | 'rgb' | 'hsl';
export type UUIColorPickerFormatWithAlpha = UUIColorPickerFormat | 'hexa' | 'rgba' | 'hsla';
type UUIColorPickerSize = 'small' | 'medium' | 'large';
declare const UUIColorPickerElement_base: (new (...args: any[]) => import("@umbraco-ui/uui-base/lib/mixins").LabelMixinInterface) & typeof LitElement;
/**
 * @element uui-color-picker
 * @cssprop --uui-color-picker-width - The width of the color picker
 * @description
 * @fires {UUIColorPickerChangeEvent} change - Fired when the color changes
 */
export declare class UUIColorPickerElement extends UUIColorPickerElement_base {
    static styles: import("lit").CSSResult[];
    _input: UUIInputElement;
    _previewButton: HTMLButtonElement;
    _swatches: UUIColorSwatchesElement;
    private inputValue;
    private hue;
    private saturation;
    private lightness;
    private alpha;
    private _colord;
    /**
     * The current color.
     * @attr
     * @type {string}
     * @default ''
     **/
    value: string;
    /**
     * The format to use for the display value. If opacity is enabled, these will translate to HEXA, RGBA, and HSLA
     * respectively. The color picker will always accept user input in any format (including CSS color names) and convert
     * it to the desired format.
     * @attr
     * @type {UUIColorPickerFormat}
     * @default 'hex'
     */
    format: UUIColorPickerFormat;
    /**
     * The input's name attribute.
     * @attr
     * @type {string}
     * @default ''
     **/
    name: string;
    /**
     * Determines the size of the color picker's trigger. This has no effect on inline color pickers.
     * @attr
     * @type {UUIColorPickerSize}
     * @default 'medium'
     **/
    size: UUIColorPickerSize;
    /**
     * Removes the format toggle.
     * @attr
     * @type {boolean}
     * @default false
     **/
    noFormatToggle: boolean;
    /**
     * Renders the color picker inline rather than inside a dropdown.
     * @attr
     * @type {boolean}
     * @default false
     **/
    inline: boolean;
    /**
     * Disables the color picker.
     * @attr
     * @type {boolean}
     * @default false
     **/
    disabled: boolean;
    /**
     * Whether to show the opacity slider.
     * @attr
     * @type {boolean}
     * @default false
     **/
    opacity: boolean;
    /**
     * By default, the value will be set in lowercase. Set this to true to set it in uppercase instead.
     * @attr
     * @type {boolean}
     * @default false
     **/
    uppercase: boolean;
    /**
     * An array of predefined color swatches to display. Can include any format the color picker can parse, including
     * HEX(A), RGB(A), HSL(A), and CSS color names.
     */
    swatches: string[];
    connectedCallback(): void;
    /** Returns the current value as a string in the specified format. */
    getFormattedValue(format: UUIColorPickerFormat): string;
    getBrightness(lightness: number): number;
    getLightness(brightness: number): number;
    handleFormatToggle(): void;
    handleAlphaChange(event: UUIColorSliderEvent): void;
    handleHueChange(event: UUIColorSliderEvent): void;
    handleGridChange(event: UUIColorAreaEvent): void;
    handleInputChange(event: CustomEvent): void;
    handleInputKeyDown(event: KeyboardEvent): void;
    handleColorSwatchChange(event: UUIColorSwatchesEvent): void;
    handleCopy(): void;
    openColorPicker(event: Event): void;
    closeColorPicker(event: Event): void;
    handleEyeDropper(): void;
    setColor(colorString: string | HslaColor): boolean;
    setLetterCase(string: string): string;
    private _syncValues;
    private _renderColorPicker;
    private _renderSwatches;
    private _renderPreviewButton;
    render(): import("lit-html").TemplateResult<1>;
}
declare global {
    interface HTMLElementTagNameMap {
        'uui-color-picker': UUIColorPickerElement;
    }
}
export {};
